# OTLMOW-Template
[![PyPI](https://img.shields.io/pypi/v/otlmow-template?label=latest%20release)](https://pypi.org/project/otlmow-template/)
[![otlmow-template-downloads](https://img.shields.io/pypi/dm/otlmow-template)](https://pypi.org/project/otlmow-template/)
[![Unittests](https://github.com/davidvlaminck/otlmow-template/actions/workflows/unittest.yml/badge.svg)](https://github.com/davidvlaminck/otlmow-template/actions/workflows/unittest.yml)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/otlmow-template)
[![GitHub issues](https://img.shields.io/github/issues/davidvlaminck/otlmow-template)](https://github.com/davidvlaminck/otlmow-template/issues)
[![coverage](https://github.com/davidvlaminck/otlmow-template/blob/master/UnitTests/coverage.svg)](https://htmlpreview.github.io/?https://github.com/davidvlaminck/otlmow-template/blob/master/UnitTests/htmlcov/index.html)


## Summary
The main use case of otlmow-template is to provide templates for the users, depending on a given subset.

## OTLMOW Project 
This project aims to implement the Flemish data standard OTL (https://wegenenverkeer.data.vlaanderen.be/) in Python.
It is split into different packages to reduce compatibility issues
- [otlmow_model](https://github.com/davidvlaminck/OTLMOW-Model)
- [otlmow_modelbuilder](https://github.com/davidvlaminck/OTLMOW-ModelBuilder)
- [otlmow_converter](https://github.com/davidvlaminck/OTLMOW-Converter)
- [otlmow_template](https://github.com/davidvlaminck/OTLMOW-Template) (you are currently looking at this package)
- [otlmow_postenmapping](https://github.com/davidvlaminck/OTLMOW-PostenMapping)
- [otlmow_davie](https://github.com/davidvlaminck/OTLMOW-DAVIE)
- [otlmow_visuals](https://github.com/davidvlaminck/OTLMOW-Visuals)
- [otlmow_gui](https://github.com/davidvlaminck/OTLMOW-GUI)

## Installation and requirements
Currently, you need at least Python version 3.8 to use this library.

To install the OTL MOW project into your Python project, use pip to install it:
``` 
pip install otlmow_template
```
To upgrade an existing installation use:
``` 
pip install otlmow_template --upgrade
```

## Usage
#TODO
